@@ -1,24 +1,11 @@
-### write.tree.R (2006-09-09)
+### write.tree.R (2006-10-06)
 ###
 ###     Write Tree File in Parenthetic Format
 ###
 ### Copyright 2002-2006 Emmanuel Paradis
 ###
-### This file is part of the `ape' library for R and related languages.
-### It is made available under the terms of the GNU General Public
-### License, version 2, or at your option, any later version,
-### incorporated herein by reference.
-###
-### This program is distributed in the hope that it will be
-### useful, but WITHOUT ANY WARRANTY; without even the implied
-### warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-### PURPOSE.  See the GNU General Public License for more
-### details.
-###
-### You should have received a copy of the GNU General Public
-### License along with this program; if not, write to the Free
-### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-### MA 02111-1307, USA
+### This file is part of the R-package `ape'.
+### See the file ../COPYING for licensing issues.
 
 checkLabel <- function(x, ...)
 {
@@ -40,50 +27,58 @@ checkLabel <- function(x, ...)
     x
 }
 
-write.tree <- function(phy, file = "", append = FALSE, format = "Newick",
+write.tree <- function(phy, file = "", append = FALSE,
                        multi.line = TRUE, digits = 10)
 {
     if (class(phy) != "phylo")
-      stop(paste("object ", deparse(substitute(phy)),
-                 " is not of class \"phylo\""), sep = "")
+      stop('object "phy" is not of class "phylo"')
 
     brl <- !is.null(phy$edge.length)
+
+### Ne serait-il pas plus efficace de crer des node labels vides
+### "" et d'viter l'valuation if (nodelab) ????
+### Autre possibilit : crer plusieurs variants de ces fonctions
+### (au moins deux avec/sans edge.length)
+
+### Encore autre chose: les appels  which ne peuvent-ils pas
+### tre vits ??? surtout si l'arbre est en cladewise order...
+
     nodelab <- !is.null(phy$node.label)
     phy$tip.label <- checkLabel(phy$tip.label)
-    if (!is.null(nodelab))
+    if (nodelab)
       phy$node.label <- checkLabel(phy$node.label)
 
+    f.d <- paste("%.", digits, "g", sep = "")
+
     cp <- function(s) STRING <<- paste(STRING, s, sep = "")
     add.internal <- function(i) {
         cp("(")
         br <- which(phy$edge[, 1] == i)
         for (j in br) {
             desc <- phy$edge[j, 2]
-            if (desc < 0) add.internal(desc) else add.terminal(j)
+            if (desc > n) add.internal(desc) else add.terminal(j)
             if (j != br[length(br)]) cp(",")
         }
         cp(")")
-        if (nodelab) cp(phy$node.label[-i])
+        if (nodelab) cp(phy$node.label[i - n])
         if (brl) {
             cp(":")
-            cp(formatC(phy$edge.length[which(phy$edge[, 2] == i)],
-                       format = "f", digits = digits))
+            cp(sprintf(f.d, phy$edge.length[which(phy$edge[, 2] == i)]))
         }
     }
     add.terminal <- function(i) {
         cp(phy$tip.label[phy$edge[i, 2]])
         if (brl) {
             cp(":")
-            cp(formatC(phy$edge.length[i], format = "f", digits = digits))
+            cp(sprintf(f.d, phy$edge.length[i]))
         }
     }
-    mode(phy$edge) <- "numeric"
-    nb.node <- -min(phy$edge)
+    n <- length(phy$tip.label)
     STRING <- "("
-    br <- which(phy$edge[, 1] == -1)
+    br <- which(phy$edge[, 1] == n + 1)
     for (j in br) {
         desc <- phy$edge[j, 2]
-        if (desc < 0) add.internal(desc) else add.terminal(j)
+        if (desc > n) add.internal(desc) else add.terminal(j)
         if (j != br[length(br)]) cp(",")
     }
     if (is.null(phy$root.edge)) {
@@ -94,10 +89,11 @@ write.tree <- function(phy, file = "", append = FALSE, format = "Newick",
         cp(")")
         if (nodelab) cp(phy$node.label[1])
         cp(":")
-        cp(formatC(phy$root.edge, format = "f", digits = digits))
+        cp(sprintf(f.d, phy$root.edge))
         cp(";")
     }
     if (nchar(STRING) < 80) multi.line <- FALSE
+    ## <FIXME> the following does not work fine with long taxa names :(
     if (multi.line) {
         tmp <- unlist(strsplit(STRING, NULL))
         wh <- grep("[,:]", tmp)
@@ -109,6 +105,7 @@ write.tree <- function(phy, file = "", append = FALSE, format = "Newick",
         for (i in 1:length(STRING))
           STRING[i] <- paste(tmp[debut[i]:fin[i]], collapse = "")
     }
+    ## </FIXME>
     if (file == "") return(STRING)
     else cat(STRING, file = file, append = append, sep = "\n")
 }
